import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ionicons/ionicons.dart';
import 'package:random/config/theme.dart';
import 'package:random/cubit/data_cubit.dart';

class ActivityDemoPage extends StatelessWidget {
  const ActivityDemoPage({super.key});

  @override
  Widget build(BuildContext context) {
    return SizedBox.expand(
      child: Container(
        child: FittedBox(
          fit: BoxFit.contain,
          alignment: Alignment.center,
          child: SizedBox(
            height: (MediaQuery.of(context).size.height),
            width: (MediaQuery.of(context).size.width),
            child: Center(
              child: Column(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisSize: MainAxisSize.max,
                children: <Widget>[
                  Text('TOP').tr(),
                  SizedBox(height: 20),
                  persistedCounterBlock(),
                  SizedBox(height: 20),
                  Text('BOTTOM').tr(),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }

  Widget persistedCounterBlock() {
    return BlocProvider<DataCubit>(
      create: (BuildContext context) => DataCubit(),
      child: BlocBuilder<DataCubit, DataState>(
        builder: (BuildContext context, DataState state) {
          void updateCounter(int delta) {
            BlocProvider.of<DataCubit>(context).getData(
              DataState(counter: (state.counter ?? 0) + delta),
            );
          }

          return Row(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              IconButton(
                icon: Icon(Ionicons.arrow_down),
                color: appTheme.primaryColor,
                onPressed: () => updateCounter(-1),
              ),
              Padding(
                padding: EdgeInsets.all(10),
                child: Text(state.counter.toString()),
              ),
              IconButton(
                icon: Icon(Ionicons.arrow_up),
                color: appTheme.primaryColor,
                onPressed: () => updateCounter(1),
              ),
            ],
          );
        },
      ),
    );
  }
}
